/**
 *  Copyright (C) 2009 Emerson Ribeiro de Mello, Fernando Fernandes Simão
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Copyright (C) 2009 Emerson Ribeiro de Mello, Fernando Fernandes Simão
 *
 *  Este programa é software livre; você pode redistribuí-lo e/ou
 *  modificá-lo sob os termos da Licença Pública Geral GNU, conforme
 *  publicada pela Free Software Foundation; tanto a versão 2 da
 *  Licença como (a seu critério) qualquer versão mais nova.
 *
 *  Este programa é distribuído na expectativa de ser útil, mas SEM
 *  QUALQUER GARANTIA; sem mesmo a garantia implícita de
 *  COMERCIALIZAÇÃO ou de ADEQUAÇÃO A QUALQUER PROPÓSITO EM
 *  PARTICULAR. Consulte a Licença Pública Geral GNU para obter mais
 *  detalhes.
 *
 *  Você deve ter recebido uma cópia da Licença Pública Geral GNU
 *  junto com este programa; se não, escreva para a Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307, USA.
 */
package objetos;

import abstrata.Jogador;
import interfaces.BombaAniquiladora;
import interfaces.Revitalizador;
import javax.swing.JPanel;
import jogo.Jogo;

public class Tux extends Jogador implements Revitalizador, BombaAniquiladora {

    private Jogo jogo;

    public Tux(String nomeImagem, JPanel jp, int px, int py, Jogo jogo) {
        super("/imagens/tux.png", jp, px, py);
        this.jogo = jogo;
    }

    /**
     * Ao ser ativado, converte, caso seja maior que 0, os pontos de poder em pontos de vida
     * @param ativarRevitalizador converte pontos de poder em pontos de vida
     */
    @Override
    public void ativarRevitalizador(boolean ativarRevitalizador) {
        int vida = new Integer(jogo.jProgressBarVida.getValue());
        int poder = new Integer(jogo.jProgressBarPoder.getValue());
        // se o poder do personagem principal for maior que 0 e
        // a vida for menor que 100, o revitalizador é ativado
        if ((poder > 0) && (vida < 100)) {
            int revitalizador = vida + poder;
            if (revitalizador > 100) {
                // atualizando barra de vida do personagem principal
                jogo.jProgressBarVida.setValue(100);
                // atualizando barra de poder do personagem principal
                jogo.jProgressBarPoder.setValue(revitalizador - 100);
            } else {
                // atualizando barra de vida do personagem principal
                jogo.jProgressBarVida.setValue(revitalizador);
                // atualizando barra de poder do personagem principal
                jogo.jProgressBarPoder.setValue(0);
            }
        }
    }

    /**
     * Ao ser ativada, destrói todos os inimigos e respectivos disparos que estão na tela
     * Não se aplica ao chefão.
     * @param ativarBomba destrói todos os inimigos e respectivos disparos que estão na tela
     * exceto chefão
     */
    @Override
    public void ativarBombaAniquiladora() {
        // para garantir que seja ativada somente uma vez
        if (this.ativarBombaAniquiladora == false) {
            // se o poder do personagem principal estiver no máximo
            // a bomba aniquiladora é ativada
            int poder = new Integer(jogo.jProgressBarPoder.getValue());
            if (poder == 100) {
                // ativandoa bomba aniquilidora
                this.ativarBombaAniquiladora = true;
                // atualizando a barra de poder do personagem principal
                jogo.jProgressBarPoder.setValue(0);
            } else {
                this.ativarBombaAniquiladora = false;

            }
        }
    }
}
